@@ -27,7 +27,7 @@ from itools.csv import CSVFile, Table, UniqueError
 from itools.csv.table import parse_table, unfold_lines
 from itools.datatypes import Date, Integer, Unicode, URI, String
 from itools.fs import lfs
-from itools.handlers import RWDatabase, ro_database
+from itools.handlers import RODatabase
 
 
 TEST_DATA_1 = """python,http://python.org/,52343,2003-10-23
@@ -38,7 +38,7 @@ TEST_DATA_2 = 'one,two,three\nfour,five,six\nseven,eight,nine'
 TEST_SYNTAX_ERROR = '"one",,\n,"two",,\n,,"three"'
 
 
-rw_database = RWDatabase(fs=lfs)
+ro_database = RODatabase(fs=lfs)
 
 
 class Languages(CSVFile):
@@ -166,11 +166,11 @@ class CSVTestCase(TestCase):
 
 
     def test_set_state_in_file_resource(self):
-        handler = rw_database.get_handler('tests/test.csv', CSVFile)
+        handler = ro_database.get_handler('tests/test.csv', CSVFile)
         handler.add_row(['d1', 'e1', 'f1'])
         handler.save_state()
 
-        handler2 = rw_database.get_handler('tests/test.csv', CSVFile)
+        handler2 = ro_database.get_handler('tests/test.csv', CSVFile)
         self.assertEqual(handler2.get_row(3), ['d1', 'e1', 'f1'])
         handler2.del_row(3)
         handler2.save_state()
@@ -343,7 +343,7 @@ class TableTestCase(TestCase):
         agenda = Agenda(string=agenda_file)
         agenda.save_state_to('tests/agenda')
         # Change
-        agenda = rw_database.get_handler('tests/agenda', Agenda)
+        agenda = ro_database.get_handler('tests/agenda', Agenda)
         fake = agenda.add_record({'firstname': u'Toto', 'lastname': u'Fofo'})
         agenda.add_record({'firstname': u'Albert', 'lastname': u'Einstein'})
         agenda.del_record(fake.id)
